@@ -1,9 +1,18 @@
 from ..stage import GraderStage, Registrar
-from ..task import GenericResult
+from ..task import Result
 from .check import CheckResult
 from .build import BuildResult
 
 
+class SetupResult(Result):
+    """Common result for generic tasks."""
+
+    kind = "generic"
+
+    def __init__(self, passed: bool = True, complete: bool = True, **details):
+        super().__init__(complete=complete, passed=passed, details=details)
+
+
 class SetupStage(GraderStage):
     """Setup endpoints."""
 
@@ -12,7 +21,7 @@ class SetupStage(GraderStage):
     def generic(self, **details) -> Registrar:
         """Generic tasks."""
 
-        return self.create_registrar(details, GenericResult)
+        return self.create_registrar(details, SetupResult)
 
     def build(self, **details) -> Registrar:
         """Compilation."""
