@@ -1,8 +1,17 @@
+from ..task import Result
 from ..stage import GraderStage, Registrar
-from ..task import GenericResult
 from .cleanup import CleanupResult
 
 
+class TeardownResult(Result):
+    """Common result for generic tasks."""
+
+    kind = "generic"
+
+    def __init__(self, passed: bool = True, complete: bool = True, **details):
+        super().__init__(complete=complete, passed=passed, details=details)
+
+
 class TeardownStage(GraderStage):
     """Teardown endpoints."""
 
@@ -11,7 +20,7 @@ class TeardownStage(GraderStage):
     def generic(self, **details) -> Registrar:
         """Generic tasks."""
 
-        return self.create_registrar(details, GenericResult)
+        return self.create_registrar(details, TeardownResult)
 
     def cleanup(self, **details) -> Registrar:
         """Deleting files."""
