@@ -10,4 +10,4 @@ class CleanupResult(Result):
     kind = "cleanup"
 
     def __init__(self, passed: bool = True, complete: bool = True, **details):
-        super().__init__(complete=complete, passed=passed, details=details)
+        super().__init__(complete=complete, passed=passed, **details)
