@@ -1,5 +1,5 @@
 from typing import Optional
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from pathlib import Path
 
 from ...task import Result
@@ -21,9 +21,14 @@ class CodeLocation:
         return f"{self.path}"
 
 
-@dataclass
+@dataclass(init=False)
 class CodeResult(Result):
     """The result of a correctness case."""
 
-    description: str
-    location: CodeLocation
+    description: str = field(init=False)
+    location: CodeLocation = field(init=False)
+
+    def __init__(self, complete: bool, passed: bool, description: str, location: CodeLocation, **details):
+        super().__init__(complete=complete, passed=passed, **details)
+        self.description = description
+        self.location = location
